#[non_exhaustive]pub enum ResourceLimit {
Depth,
ItemCount,
ExpandedSize,
}Expand description
Which parser ceiling a file hit.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Depth
Nesting depth. Guards against stack exhaustion, which aborts the process and so cannot be recovered from after the fact.
ItemCount
Number of objects, segments, or chunks.
ExpandedSize
Total bytes a single structure may expand to.