#[non_exhaustive]pub struct StripOptions {
pub inspect: InspectOptions,
pub limits: ParseLimits,
}Expand description
What a caller wants from a strip.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inspect: InspectOptionsWhether the returned report names the values that were removed.
Off by default, for the reason in crate::report: a report is easy to redirect into
a file, and a file naming everything just removed is a durable copy of the secret.
limits: ParseLimitsParser ceilings.