inspect_bytes

Function inspect_bytes 

pub fn inspect_bytes(
    data: &[u8],
    options: &InspectOptions,
) -> Result<MetadataReport>
Report what metadata data contains, without modifying anything.

Errors

Returns StryptError::UnsupportedFormat or StryptError::UnrecognisedFormat when there is no handler, and the handler’s own errors otherwise. There is no variant of this function that quietly returns an empty report for a file it did not understand.