#[non_exhaustive]pub enum MetadataValue {
Text(String),
Opaque {
bytes: u64,
},
}Expand description
A metadata value, when the caller asked for values.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Text(String)
A decoded textual value.
Opaque
A value that is not text, or not valid text. Only its length is carried: rendering an arbitrary binary blob into a report has no benefit to the user and every opportunity to leak.